@@ -17,6 +17,10 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 
 #include <glib/gstdio.h>
@@ -180,6 +184,7 @@ JsonNode *torrent_get(gint64 id)
     json_array_add_string_element(fields, FIELD_ADDED_DATE);
     json_array_add_string_element(fields, FIELD_DOWNLOADEDEVER);
     json_array_add_string_element(fields, FIELD_UPLOADEDEVER);
+    json_array_add_string_element(fields, FIELD_CORRUPTEVER);
     json_array_add_string_element(fields, FIELD_SIZEWHENDONE);
     json_array_add_string_element(fields, FIELD_QUEUE_POSITION);
     json_array_add_string_element(fields, FIELD_ID);
