@@ -17,6 +17,10 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -176,6 +180,11 @@ gint64 torrent_get_uploaded(JsonObject * t)
     return json_object_get_int_member(t, FIELD_UPLOADEDEVER);
 }
 
+gint64 torrent_get_corrupted(JsonObject * t)
+{
+    return json_object_get_int_member(t, FIELD_CORRUPTEVER);
+}
+
 gint64 torrent_get_have_valid(JsonObject * t)
 {
     return json_object_get_int_member(t, FIELD_HAVEVALID);
