@@ -17,7 +17,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <stdlib.h>
 #include <string.h>
@@ -490,7 +492,7 @@ header_callback(void *ptr, size_t size, size_t nmemb, void *data)
     return (nmemb * size);
 }
 
-trg_tls *trg_tls_new(TrgClient * tc)
+static trg_tls *trg_tls_new(TrgClient * tc)
 {
     trg_tls *tls = g_new0(trg_tls, 1);
 
@@ -627,7 +629,7 @@ int trg_http_perform(TrgClient * tc, trg_request *request, trg_response * rsp)
     return trg_http_perform_inner(tc, request, rsp, TRUE);
 }
 
-void trg_request_free(trg_request *req) {
+static void trg_request_free(trg_request *req) {
 	g_free(req->body);
 	g_free(req->url);
 	g_free(req->cookie);
@@ -771,16 +773,6 @@ dispatch_async(TrgClient * tc, JsonNode * req,
     return dispatch_async_common(tc, trg_req, callback, data);
 }
 
-gboolean
-dispatch_async_str(TrgClient * tc, gchar * body,
-                   GSourceFunc callback, gpointer data)
-{
-    trg_request *trg_req = g_new0(trg_request, 1);
-    trg_req->body = body;
-
-    return dispatch_async_common(tc, trg_req, callback, data);
-}
-
 gboolean async_http_request(TrgClient *tc, gchar *url, const gchar *cookie, GSourceFunc callback, gpointer data) {
 	trg_request *trg_req = g_new0(trg_request, 1);
 	trg_req->url = g_strdup(url);
